@@ -31,7 +31,9 @@ Defines:
 #define INDPARAMS        "individuals"
 
 #define HABNAMES         "habitats"     
-#define STAGENAME 	 "stages"       
+#define STAGENAME 	 "stages"
+#define XDIMNAME 	 "xdim"
+#define YDIMNAME 	 "ydim"       
 #define	LNUMNAME	 "locusnum"     
 #define	ENUMNAME	 "numepochs"    
 #define	CGNAME		 "currentgen"   
@@ -77,10 +79,10 @@ Defines:
 ///.........................................................................
 #define SELFRATENAME     "selfing"
 
-///input/output of landscapes to/from metasim lib
-extern "C" SEXP read_landscape(SEXP fn);
+///input/output of landscapes to/from metasim lib 
+extern "C" SEXP read_landscape(SEXP fn); //DEPRECATED/NO CALLS FROM R NOW
 //extern "C" SEXP convert_metasim_to_R(Landscape_statistics &L);
-extern "C" SEXP write_landscape(SEXP fn, SEXP Rland);
+extern "C" SEXP write_landscape(SEXP fn, SEXP Rland); //DEPRECATED/NO CALLS FROM R NOW
 //extern "C" void convert_R_to_metasim(SEXP Rland, Landscape_statistics &L);
 extern "C" SEXP getListElement(SEXP list, const char *str);
 
@@ -107,7 +109,11 @@ extern "C" SEXP compress_landscape(SEXP Rland);
 extern "C" SEXP num_demo_cols();
 ///utility functions
 ///convert a landscape into a format that the weir fst calculations in R can use.
-extern "C" SEXP l2w(SEXP Rland, SEXP numind);
+extern "C" SEXP l2w(SEXP Rland, SEXP numind); //DEPRECATED NO CALL FROM R
+
+///return the maximum loci compiled into this version of rmetasim
+extern "C" SEXP num_loci_poss();
+
 
 ///
 ///this is C code to calculate relatedness
@@ -119,3 +125,22 @@ extern "C" SEXP relateinternal(SEXP ind, SEXP acnp);
 
 extern "C" SEXP test(SEXP mat1, SEXP mat2);
 
+
+
+static const R_CallMethodDef CallEntries[] = {
+    {"advance_landscape",   (DL_FUNC) &advance_landscape,   1},
+    {"carry_landscape",     (DL_FUNC) &carry_landscape,     1},
+    {"clean_landscape",     (DL_FUNC) &clean_landscape,     1},
+    {"compress_landscape",  (DL_FUNC) &compress_landscape,  1},
+    {"extinct_landscape",   (DL_FUNC) &extinct_landscape,   1},
+    {"iterate_landscape",   (DL_FUNC) &iterate_landscape,   4},
+    //    {"landlambda",          (DL_FUNC) &landlambda,          1},
+    {"num_demo_cols",       (DL_FUNC) &num_demo_cols,       0},
+    {"num_loci_poss",       (DL_FUNC) &num_loci_poss,       0},
+    {"populate_Rland",      (DL_FUNC) &populate_Rland,      2},
+    {"relateinternal",      (DL_FUNC) &relateinternal,      2},
+    {"reproduce_landscape", (DL_FUNC) &reproduce_landscape, 1},
+    {"survive_landscape",   (DL_FUNC) &survive_landscape,   1},
+    {"test",                (DL_FUNC) &test,                2},
+    {NULL, NULL, 0}
+};
